{% extends "fleetcomp/base.html" %}
{% load evelinks %}
{% load i18n %}
{% block content %}
    <div class="row row-cols-1 row-cols-md-6 g-4">
        {% for commander in commanders %}
            <div class="col">
                <div class="card">
                    <img src="{{ commander.character_id|character_portrait_url:256 }}"
                         class="card-img-top"
                         alt="{{ commander.character_name }} portrait">
                    <div class="card-body">
                        <h5 class="card-title">{{ commander.character_name }}</h5>
                        <form method="post" action="">
                            {% csrf_token %}
                            <input type="hidden"
                                   name="commander_id"
                                   id="commander_id"
                                   value="{{ commander.id }}">
                            <button type="submit" class="btn btn-primary">{% translate "Snapshot this character's fleet" %}</button>
                        </form>
                    </div>
                </div>
            </div>
        {% endfor %}
    </div>
{% endblock %}
