# Generated by Django 4.2.21 on 2025-06-25 19:33
# Additional template models added by manually by T'rahk

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("eveuniverse", "0010_alter_eveindustryactivityduration_eve_type_and_more"),
        ("fleetcomp", "0001_initial"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="CustomGrouping",
            new_name="ShipGrouping",
        ),
        migrations.AddField(
            model_name="shipgrouping",
            name="column_index",
            field=models.PositiveIntegerField(
                default=0,
                help_text="Index of the column this grouping should be a part of",
            ),
        ),
    ]
