{% load i18n %}
<li class="nav-item">
    <a class="nav-link" href="{% url "fleetcomp:add_own_snapshot" %}">
        <i class="fa-solid fa-users-viewfinder"></i>
        <span class="d-md-inline m-2">{% translate "Snapshot your fleet" %}</span>
    </a>
</li>
{# TODO lock behind a role #}
<li class="nav-item">
    <a class="nav-link" href="{% url "fleetcomp:add_other_snapshot" %}">
        <i class="fa-solid fa-users-viewfinder"></i>
        <span class="d-md-inline m-2">{% translate "Snapshot another's fc fleet" %}</span>
    </a>
</li>
