{% load i18n %}
<li class="nav-item">
    <a class="nav-link" href="{% url 'fleetcomp:index' %}">
        <i class="fa-solid fa-users-line"></i>
        <span class="d-md-inline m-2">{% translate "View fleet snapshots" %}</span>
    </a>
</li>
