{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}
{% block page_title %}
    {% translate "Fleet composition" %}
{% endblock %}
{% block content %}{% endblock %}
{% block header_nav_collapse_left %}
    {% include 'fleetcomp/partials/left_header.html' %}
{% endblock %}
{% block header_nav_collapse_right %}
    {% include 'fleetcomp/partials/right_header.html' %}
{% endblock %}
{% block extra_javascript %}{% endblock %}
{% block extra_css %}{% endblock %}
{% block extra_script %}{% endblock %}
